# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).


## [v1.0.1] - 2025-06-03

### Bug fixes

* fix(pyproject.toml): update version scheme ([`f5ce64c`](https://github.com/tom65536/syndantic/commit/f5ce64c9706a779032105eadba2e2de859e6159f))
## [v1.0.0] - 2025-06-02

### Bug fixes

* fix: update ci workflow ([`7242f64`](https://github.com/tom65536/syndantic/commit/7242f64999fa17a246afce42ec5b03c4571bc350))
## [v0.0.3] - 2025-06-02

### Bug fixes

* fix: rebase conflicts feom main

Automatically generated by python-semantic-release ([`c111cd5`](https://github.com/tom65536/syndantic/commit/c111cd5b39dda8dca5019d9adffef2ecfe1b6d45))
## [v0.0.2] - 2025-06-02

### Bug fixes

* fix: update CI workflow ([`113345b`](https://github.com/tom65536/syndantic/commit/113345b6e76260ec7f0e89d545b09aed4cbd3090))
## [v0.0.1] - 2025-06-01

### Bug fixes

* fix: add CI step for writing version files ([`96bb22d`](https://github.com/tom65536/syndantic/commit/96bb22d8e589ec18ab3cf7f7d0b54258be775053))

* fix: install ruff ([`ae2f611`](https://github.com/tom65536/syndantic/commit/ae2f61123005a8762708561a2fb77c3b8603d4d8))

* fix: ci pipeline ([`07f092d`](https://github.com/tom65536/syndantic/commit/07f092dd3147845422a726ac8e086d518ba3f8b6))

* fix: unit test added ([`6882dcd`](https://github.com/tom65536/syndantic/commit/6882dcd76d26b4236a68ee464663ebd64ea9e2bc))

### Unknown

* misc: initial commit ([`4e833b0`](https://github.com/tom65536/syndantic/commit/4e833b08e6b4cd326f2974c9693f56f661e78e68))

* Initial commit ([`b2aa249`](https://github.com/tom65536/syndantic/commit/b2aa249fa56ea5db4e0a203afb9f73feae3f45eb))
